@@ -7,7 +7,6 @@
 #'   \item{BestModel}{Contains the information criteria and the corresponding parameter estimates of the best fitting model.}
 #'   \item{Figures}{Contains figures showing the performance of the FAMoS.}
 #'   \item{Fits}{Contains the fitted parameter values of each of the tested models.}
-#'   \item{LogFiles}{Contains the log files of the individual model fitting runs.}
 #'   \item{TestedModels}{Contains the binary information of all of the tested models.}
 #'   }
 #'
@@ -28,9 +27,6 @@ make.directories <- function(homedir) {
   if(!dir.exists(paste0(dir, "/Fits"))){
     dir.create(paste0(dir, "/Fits"), showWarnings = F)
   }
-  if(!dir.exists(paste0(dir, "/LogFiles"))){
-    dir.create(paste0(dir, "/LogFiles"), showWarnings = F)
-  }
   if(!dir.exists(paste0(dir, "/TestedModels"))){
     dir.create(paste0(dir, "/TestedModels"), showWarnings = F)
   }
